@@ -1,12 +1,12 @@
-use std::fs;
-use std::path::Path;
+use std::{fs, path::Path};
 
 use clap::App;
 use clap_generate::{generate_to, Generator};
 
 /// # Panics
 ///
-/// Will panic if it can't work out the application's binary name, or create the build directory
+/// Will panic if it can't work out the application's binary name, or create the
+/// build directory
 pub fn generate<T>(app: &App, dir: &Path)
 where
     T: Generator,
